function lastPersonIdx = getLastPersonExtended(leftLean)
    % This function gets the last person index (1-20) of the Cranberry
    % Sauce problem via Monte-Carlo simulation.  Starting from person 1,
    % the cranberry saunce is passed either to the current person's left
    % (person 20) or to person 1's right (person 2), with equally likely
    % probability (1/2).  Then the process continues.  This function
    % generates and returns the index of the last person to have the
    % cranberry sauce passed.
    
    % In this extended version, we introduce a "lean" for passing to the
    % left.  That is, if leftLean is > 0.5, the current sauce holder is
    % more likely to pass to his/her left, and vice versa.
    
    lastPersonIdx = -1;
    
    CranSauceRcvd = zeros(1, 20); % Cranberry sauce received tracker
    CranSauceRcvd(1) = 1; % You start by having the cran sauce.
    CurrentSauceHolder = 0; % You are person 0 in the simulation for easy mod op;
    % Matlab, however, is 1-based.
    
    while true
       passLeft = rand < leftLean;
       if passLeft
           CurrentSauceHolder = mod(CurrentSauceHolder-1, 20);
       else
           CurrentSauceHolder = mod(CurrentSauceHolder+1, 20);
       end
       
       % Update the CranSauceRcvd Info
       CranSauceRcvd(CurrentSauceHolder+1) = 1; % Again Matlab is 1-based
       % fprintf('Current saunce holder is person %d\n.', CurrentSauceHolder+1);
       if all(CranSauceRcvd)
           lastPersonIdx = CurrentSauceHolder+1;
           break;
       end
    end
end

